module.exports = function (grunt) {
	grunt.config.init({
		pkg: grunt.file.readJSON('package.json'),
		aws: grunt.file.readJSON('aws_credentials.json'),
		meta: {
			banner: '/*! <%= pkg.name %> - v<%= pkg.version %> - ' +
				'<%= grunt.template.today("yyyy-mm-dd HH:MM") %>\n' +
				'* <%= pkg.homepage %>\n' +
				'* Copyright (c) <%= grunt.template.today("yyyy") %> <%= pkg.author.name %> */\n'
		},
		jshint: {
			all: {
				src: ['src/*.js', 'Gruntfile.js'],
				options: {
					nonew: true,
					browser: true,
					devel: true,
					eqnull: true
				}
			}
		},
		concat: {
			all: {
				src: [
					'src/intro.txt',
					'src/features.js',
					'src/dispatcher.js',
					'src/task_queue.js',
					'src/dom.js',
					'src/geolocation.js',
					'src/proxy.js',
					'src/ajax.js',
					'src/ajax_xhr.js',
					'src/ajax_postmessage.js',
					'src/api.js',
					'src/file_upload.js',
					'src/form_submit.js',
					'src/permissions.js',
					'src/permission.js',
					'src/session.js',
					'src/storage.js',
					'src/shopping_list.js',
					'src/utils.js',
					'src/client.js',
					'src/outro.txt'
				],
				dest: 'eta.js'
			}
		},
		uglify: {
			options: {
				banner: '<%= meta.banner %>',
				report: 'min',
				mangle: {
					except: ['undefined']
				},
				compress: {
					global_defs: {
						DEBUG: false
					}
				}
			},
			all: {
				files: {
					'eta.min.js': ['eta.js']
				}
			}
		},
		watch: {
			options: {
				nospawn: true
			},
			all: {
				files: 'src/**/*',
				tasks: ['test', 'concat']
			}
		},
		s3: {
			options: {
				key: '<%= aws.access_key_id %>',
				secret: '<%= aws.secret_access_key %>',
				bucket: '<%= aws.bucket %>',
				access: 'public-read',
				headers: {
					// Cache for two hours.
					'Cache-Control': 'max-age=' + 60 * 60 * 2
				},
				gzip: true
			},
			production: {
				upload: [
					{
						src: 'eta.js',
						dest: 'v<%= pkg.version %>/eta.js'
					},
					{
						src: 'eta.min.js',
						dest: 'v<%= pkg.version %>/eta.min.js'
					}
				]
			}
		},
		cloudfront_clear: {
			production: {
				resourcePaths: ['/v<%= pkg.version %>/eta.js', '/v<%= pkg.version %>/eta.min.js'],
				access_key: '<%= aws.access_key_id %>',
				secret_key: '<%= aws.secret_access_key %>',
				dist: '<%= aws.distribution %>'
			}
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-s3');
	grunt.loadNpmTasks('grunt-cloudfront-clear');

	grunt.loadTasks('tasks');

	grunt.registerTask('dev', ['test', 'concat', 'server', 'watch']);
	grunt.registerTask('prod', ['test', 'concat', 'uglify']);
	grunt.registerTask('prod-upload', ['prod', 's3', 'cloudfront_clear']);
	grunt.registerTask('test', 'jshint');
};
