// Event dispatcher.
ETA.Dispatcher = function () {};

// Add an event listener.
//
// @param		String			eventName		The name of the event
// @param		Function		callback		The function callback
// @return		void
ETA.Dispatcher.prototype.addEventListener = function (eventName, callback) {
	this._events = this._events || {};
	if (typeof eventName === 'string') eventName = eventName.split(' ');
	for (var i = 0, len = eventName.length; i < len; i++) {
		this._events[eventName[i]] = this._events[eventName[i]] || [];
		if (this._events[eventName[i]]) {
			this._events[eventName[i]].unshift(callback);
		}
	}
};

// Remove an existing event listener.
//
// @param		String			eventName		The name of the event
// @param		Function		callback		The function callback
// @return		Boolean							Whether the event was removed or not
ETA.Dispatcher.prototype.removeEventListener = function (eventName, callback) {
	this._events = this._events || {};
	var listeners = this._events[eventName] || [];
	var all = this._events.all;
	if (all) listeners = listeners.concat(all);
	for (var i = listeners.length - 1; i >= 0; --i) {
		if (listeners[i] === callback) {
			listeners.splice(i, 1);
			return true;
		}
	}
	return false;
};

// Dispatch an array of listeners.
//
// @param		Array			listeners		The listeners
// @return		void
ETA.Dispatcher.prototype.dispatchEvents = function (listeners, args) {
	var len = listeners.length;
	while (len--) {
		listeners[len].apply(null, args);
	}
};

// Dispatch an event.
//
// @param		String			eventName		The name of the event
// @return		void
ETA.Dispatcher.prototype.dispatch = function (eventName) {
	this._events = this._events || {};
	var listeners = this._events[eventName] || [];
	var allListeners = this._events.all || [];
	var args = Array.prototype.slice.call(arguments, 1);

	if (listeners) this.dispatchEvents(listeners, args);
	if (allListeners) this.dispatchEvents(allListeners, arguments);
};

// Copy the dispatcher to any object.
//
// @param		Object			destObject		The destination object
// @return		void
ETA.Dispatcher.mixin = function (destObject) {
	var props = ['addEventListener', 'removeEventListener', 'dispatchEvents', 'dispatch'];

	for (var i = 0; i < props.length; i++) {
		if (typeof destObject === 'function') {
			destObject.prototype[props[i]] = ETA.Dispatcher.prototype[props[i]];
		} else {
			destObject[props[i]] = ETA.Dispatcher.prototype[props[i]];
		}
	}
};
