// Geolocation.
//
// @param		Object			attributes		The attributes
ETA.Geolocation = function (attributes) {
	this.attributes = attributes || {};
	this.RADIUS_MIN = this.radiuses[0];
	this.RADIUS_MAX = this.radiuses[this.radiuses.length - 1];
};

ETA.Dispatcher.mixin(ETA.Geolocation);

// Predefined radiuses in metres.
ETA.Geolocation.prototype.radiuses = [
	100, 150, 200, 250, 300, 350, 400, 450, 500,
	600, 700, 800, 900, 1000,
	1500, 2000, 2500, 3000, 3500, 4000, 4500, 5000, 5500, 6000, 6500, 7000, 7500, 8000, 8500, 9000, 9500, 10000,
	15000, 20000, 25000, 30000, 35000, 40000, 45000, 50000, 55000, 60000, 65000, 70000, 75000, 80000, 85000, 90000, 95000, 100000,
	200000, 300000, 400000, 500000, 600000, 700000
];

// Check if a geolocation has been set.
//
// @return		Boolean							True if a geolocation has been set
ETA.Geolocation.prototype.has = function () {
	return !!(this.get('latitude') && this.get('longitude'));
};

// Get attribute key value.
//
// @param		String			key				The key
// @return		Mixed							The attribute key value
ETA.Geolocation.prototype.get = function (key) {
	return this.attributes[key];
};

// Set attribute key value.
//
// @param		Object			attributes		The new attributes
// @param		Boolean			silent			If the change should trigger an event or not
// @return		void
ETA.Geolocation.prototype.set = function (attributes, silent) {
	var changes = false;
	for (var key in attributes) {
		if (this.attributes[key] !== attributes[key]) {
			this.attributes[key] = attributes[key];
			changes = true;
		}
	}
	if (changes) {
		var clone = this.clone();
		this.dispatch('_change', clone);
		if (!silent) this.dispatch('change', clone);

		if (DEBUG) {
			console.log('ETA.Geolocation', 'Changed', clone);
		}
	}
};

// Clone attributes.
//
// @return		Object							The cloned attributes
ETA.Geolocation.prototype.clone = function () {
	return ETA.utils.clone(this.attributes);
};

// Reset attributes.
//
// @param		Boolean			silent			True if no events should be propagated
// @return		void
ETA.Geolocation.prototype.reset = function (silent) {
	this.attributes = {};
	this.dispatch('_reset');
	if (!silent) this.dispatch('reset');
};

// Get distance between the user's location and another point.
//
// @param		Number			latitude2		The second latitude
// @param		Number			longitude2		The second longitude
// @return		Number							The distance in metres.
ETA.Geolocation.prototype.getDistance = function (latitude2, longitude2) {
	var latitude1 = this.get('latitude');
	var longitude1 = this.get('longitude');

	if (latitude1 != null && longitude1 != null && latitude2 != null && longitude2 != null) {
		return ETA.utils.getDistance(latitude1, longitude1, latitude2, longitude2);
	}
};
