// Queue a task.
//
// @param		Function		task			The task to be worked on
ETA.TaskQueue = function (task) {
	// A task has to be a function.
	this.task = typeof task === 'function' ? task : function () {};
	this.running = false;
	this.queue = [];
};

// Resolve all callbacks in the queue stack and run again.
//
// @return		void
ETA.TaskQueue.prototype.resolve = function () {
	for (var key in this.queue) this.queue[key](null);
	this.stopRun();
	this.run();
};

// Reject all callbacks in the queue stack and run again.
//
// @return		void
ETA.TaskQueue.prototype.reject = function (err) {
	for (var key in this.queue) this.queue[key](err);
	this.stopRun();
	this.run();
};

// Go through all callbacks in the queue stack if not already running.
// It will keep calling itself until the queue is empty.
//
// @return		void
ETA.TaskQueue.prototype.run = function () {
	if (this.running || this.queue.length === 0) return;
	var self = this;
	this.running = true;
	this.task(function (err) {
		if (!err) {
			self.resolve();
		} else {
			self.reject(err);
		}
	});
};

// Reset the queue stack and stop running.
//
// @return		void
ETA.TaskQueue.prototype.stopRun = function () {
	this.queue = [];
	this.running = false;
};

// Use this to async subscribe to the task.
//
// @param		Function		callback		The callback for when the task has resolved
// @return		void
ETA.TaskQueue.prototype.invoke = function (callback) {
	this.queue.push(callback);
	this.run();
};
