test('ETA.ShoppingList - set list', function () {
	var client = ETAUnit.getClient();
	var shoppingList = new ETA.ShoppingList(null, client);
	var list = shoppingList.setList({
		name: 'My shopping list',
		access: 'private'
	});
	equal(shoppingList.lists.length, 1);
});

test('ETA.ShoppingList - set item', function () {
	expect(1);
	var client = ETAUnit.getClient();
	var shoppingList = new ETA.ShoppingList(null, client);
	var item = shoppingList.setItem({
		description: 'My item'
	}, 'testid');
	strictEqual(item.count, 1);
});

test('ETA.ShoppingList - synchronize lists', function () {
	expect(9);
	var client = ETAUnit.getClient();
	var shoppingList = new ETA.ShoppingList(null, client);
	shoppingList.addEventListener('lists:sync', function (removed, added, changed) {
		strictEqual(removed.length, 1);
		strictEqual(added.length, 1);
		strictEqual(changed.length, 1);
		strictEqual(removed[0].id, list3.id);
		strictEqual(added[0].id, 'new-id');
		strictEqual(added[0].name, 'new-name');
		strictEqual(changed[0].id, list2.id);
		strictEqual(changed[0].name, 'changed-name');
		strictEqual(shoppingList.lists.length, 3);
	});

	var list1 = shoppingList.setList({
		name: 'list1'
	});
	var list2 = shoppingList.setList({
		name: 'list2'
	});
	var list3 = shoppingList.setList({
		name: 'list3'
	});

	shoppingList.synchronizeLists(
		[
			list1,
			{
				id: list2.id,
				name: 'changed-name',
				modified: ETA.utils.toISOString(new Date(new Date().getTime() + 1000))
			},
			{
				id: 'new-id',
				name: 'new-name',
				modified: ETA.utils.toISOString(new Date())
			}
		]
	);
});

test('ETA.ShoppingList - synchronize items', function () {
	expect(10);
	var client = ETAUnit.getClient();
	var shoppingList = new ETA.ShoppingList(null, client);
	shoppingList.addEventListener('items:sync', function (list, removed, added, changed) {
		strictEqual(list, list1.id);
		strictEqual(removed.length, 1);
		strictEqual(added.length, 1);
		strictEqual(changed.length, 1);
		strictEqual(removed[0].id, item3.id);
		strictEqual(added[0].id, 'new-id');
		strictEqual(added[0].description, 'new-description');
		strictEqual(changed[0].id, item2.id);
		strictEqual(changed[0].description, 'changed-description');
		strictEqual(shoppingList.getItems(list).length, 3);
	});

	var list1 = shoppingList.setList({
		name: 'list'
	});
	var item1 = shoppingList.setItem({
		description: 'item1'
	}, list1.id);
	var item2 = shoppingList.setItem({
		description: 'item2'
	}, list1.id);
	var item3 = shoppingList.setItem({
		description: 'item3'
	}, list1.id);

	shoppingList.synchronizeItems(
		[
			item1,
			{
				id: item2.id,
				description: 'changed-description',
				modified: ETA.utils.toISOString(new Date(new Date().getTime() + 1000))
			},
			{
				id: 'new-id',
				description: 'new-description',
				modified: ETA.utils.toISOString(new Date())
			}
		],
		list1.id
	);
});
